<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Obecná nastavení</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="35"/>
      <source>General OpenSCAD Settings</source>
      <translation>Všeobecné nastavení OpenSCADu</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="43"/>
      <source>OpenSCAD executable</source>
      <translation>Spustitelný soubor OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="56"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Cesta pro spuštění OpenSCADu</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="74"/>
      <source>OpenSCAD import</source>
      <translation>Import z OpenSCADu</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="82"/>
      <source>Print debug information in the Console</source>
      <translation>Tisknout na konzoli ladící informace</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="99"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Je-li zaškrtnuto, budou funkce ve stromovém zobrazení</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="102"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Použít ViewProvider ve stromovém zobrazení</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="119"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Pokud je toto políčko zaškrtnuto, Multmatrix objekt bude Parametrický</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="122"/>
      <source>Use Multmatrix Feature</source>
      <translation>Použít prvek Multmatrix</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="139"/>
      <location filename="../ui/openscadprefs-base.ui" line="162"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Maximální počet stěn mnohoúhelníku, hranolu nebo jehlanu. Pokud je větší než tato hodnota, objekt je považován za kulatý. Při hodnotě 0:bez omezení</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="142"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Maximální počet stěn mnohoúhelníku (fn)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="182"/>
      <source>Send to OpenSCAD via:</source>
      <translation>Odeslat do OpenSCAD přes:</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="195"/>
      <source>The transfer mechanism for getting data to and from OpenSCAD</source>
      <translation>Přenosový mechanismus pro získávání dat do az OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="205"/>
      <source>Standard temp directory</source>
      <translation>Standardní dočasný adresář</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="210"/>
      <source>User-specified directory</source>
      <translation>Uživatelem zadaný adresář</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="215"/>
      <source>stdout pipe (requires OpenSCAD &gt;= 2021.1)</source>
      <translation>stdout pipe (vyžaduje OpenSCAD &gt;= 2021.1)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="227"/>
      <source>Transfer directory</source>
      <translation>Adresář převodu</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="240"/>
      <source>The path to the directory for transferring files to and from OpenSCAD</source>
      <translation>Cesta k adresáři pro přenos souborů do az OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="258"/>
      <source>OpenSCAD export</source>
      <translation>OpenSCAD export</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="266"/>
      <source>Maximum fragment size</source>
      <translation>Maximální velikost fragmentu</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="289"/>
      <source>angle (fa)</source>
      <translation>úhel (fa)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="385"/>
      <source>Convexity</source>
      <translation>Konvexnost</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="286"/>
      <location filename="../ui/openscadprefs-base.ui" line="296"/>
      <source>Minimum angle for a fragment</source>
      <translation>Minimální úhel pro fragment</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="328"/>
      <location filename="../ui/openscadprefs-base.ui" line="353"/>
      <source>Minimum size of a fragment</source>
      <translation>Minimální velikost fragmentu</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="331"/>
      <source>size (fs)</source>
      <translation>Velikost (fs)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="359"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="422"/>
      <source>Mesh fallback</source>
      <translation>Nouzová síť</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="442"/>
      <location filename="../ui/openscadprefs-base.ui" line="459"/>
      <source>Deflection</source>
      <translation>Průhyb</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="445"/>
      <source>deflection</source>
      <translation>průhyb</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="452"/>
      <source>Triangulation settings</source>
      <translation>Nastavení triangulace</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="../../InitGui.py" line="130"/>
      <source>It looks like you may be using a Snap version of OpenSCAD.</source>
      <translation>Vypadá to, že možná používáte Snap verzi OpenSCAD.</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="135"/>
      <location filename="../../InitGui.py" line="148"/>
      <source>If OpenSCAD execution fails to load the temporary file, use FreeCAD's OpenSCAD Workbench Preferences to change the transfer mechanism.</source>
      <translation>Pokud se při spuštění OpenSCAD nepodaří načíst dočasný soubor, změňte mechanismus přenosu pomocí předvoleb OpenSCAD Workbench FreeCAD.</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="143"/>
      <source>It looks like you may be using a sandboxed version of FreeCAD.</source>
      <translation>Vypadá to, že možná používáte sandboxovou verzi FreeCADu.</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="92"/>
      <source>Unable to explode %s</source>
      <translation>Nelze rozložit %s</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="139"/>
      <source>Convert Edges to Faces</source>
      <translation>Převést hrany na tváře</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="301"/>
      <source>Please select 3 objects first</source>
      <translation>Nejprve prosím vyberte 3 objekty</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="334"/>
      <location filename="../../OpenSCADCommands.py" line="365"/>
      <source>Add</source>
      <translation>Přidat</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="369"/>
      <source>Clear</source>
      <translation>Vyčistit</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="366"/>
      <source>Load</source>
      <translation>Načíst</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="367"/>
      <source>Save</source>
      <translation>Uložit</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="335"/>
      <location filename="../../OpenSCADCommands.py" line="368"/>
      <source>Refresh</source>
      <translation>Aktualizovat</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="336"/>
      <source>Clear code</source>
      <translation>Smazat kód</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="337"/>
      <source>Open...</source>
      <translation>Otevřít...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="338"/>
      <source>Save...</source>
      <translation>Uložit...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="339"/>
      <location filename="../../OpenSCADCommands.py" line="370"/>
      <source>as Mesh</source>
      <translation>jako Mesh</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="352"/>
      <location filename="../../OpenSCADCommands.py" line="371"/>
      <source>Add OpenSCAD Element</source>
      <translation>Přidat prvek OpenSCAD</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="428"/>
      <source>Open file</source>
      <translation>Otevřít soubor</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="430"/>
      <location filename="../../OpenSCADCommands.py" line="444"/>
      <source>OpenSCAD Files</source>
      <translation>OpenSCAD soubory</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="442"/>
      <source>Save file</source>
      <translation>Uložit soubor</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="456"/>
      <location filename="../../OpenSCADCommands.py" line="485"/>
      <source>Perform</source>
      <translation>Provést</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="482"/>
      <location filename="../../OpenSCADCommands.py" line="486"/>
      <source>Mesh Boolean</source>
      <translation>Mesh Boolean</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="487"/>
      <source>Minkowski sum</source>
      <translation>Minkowski sum</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="654"/>
      <source>OpenSCAD file contains both 2D and 3D shapes. That is not supported in this importer, all shapes must have the same dimensionality.</source>
      <translation>Soubor OpenSCAD obsahuje 2D i 3D tvary. To tento importér nepodporuje, všechny tvary musí mít stejné rozměry.</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="665"/>
      <source>Error: either all shapes must be 2D or all shapes must be 3D</source>
      <translation>Chyba: buď všechny tvary musí být 2D, nebo všechny tvary musí být 3D</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="550"/>
      <location filename="../../importCSG.py" line="1432"/>
      <source>Unsupported Function</source>
      <translation>Nepodporovaná funkce</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="550"/>
      <location filename="../../importCSG.py" line="1432"/>
      <source>Press OK</source>
      <translation>Stiskněte OK</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="100"/>
      <source>Explode Group</source>
      <translation>Rozbít skupinu</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="103"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Odstraňte fúzi, aplikujte umístění na děti a vybarvěte náhodně</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="116"/>
      <source>Color Shapes</source>
      <translation>Barva ploch</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="119"/>
      <source>Color Shapes by validity and type</source>
      <translation>Barva Tvary podle platnosti a typu</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="136"/>
      <source>Convert Edges To Faces</source>
      <translation>Převést hrany na tváře</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="156"/>
      <source>Refine Shape Feature</source>
      <translation>Funkce Upřesnit tvar</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="159"/>
      <source>Create Refine Shape Feature</source>
      <translation>Vytvořte funkci Upřesnit tvar</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="186"/>
      <source>Mirror Mesh Feature...</source>
      <translation>Funkce zrcadlení sítě...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="189"/>
      <source>Create Mirror Mesh Feature</source>
      <translation>Vytvořit funkci zrcadlení sítě</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="215"/>
      <source>Scale Mesh Feature...</source>
      <translation>Funkce měřítka...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="219"/>
      <source>Create Scale Mesh Feature</source>
      <translation>Vytvořit funkci měřítka sítě</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="245"/>
      <source>Resize Mesh Feature...</source>
      <translation>Změna velikosti síťe...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="249"/>
      <source>Create Resize Mesh Feature</source>
      <translation>Vytvořit funkci Změna velikosti sítě</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="266"/>
      <source>Increase Tolerance Feature</source>
      <translation>Zvýšit toleranci prvku</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="269"/>
      <source>Create Feature that allows increasing the tolerance</source>
      <translation>Vytvořte prvek, který umožňuje zvýšit toleranci</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="283"/>
      <source>Expand Placements</source>
      <translation>Rozbalte umístění</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="286"/>
      <source>Expand all placements downwards in the Tree view</source>
      <translation>Ve stromovém zobrazení rozbalte všechna umístění směrem dolů</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="304"/>
      <source>Replace Object</source>
      <translation>Nahradit objekt</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="307"/>
      <source>Replace an object in the Tree view. Please select old, new, and parent object</source>
      <translation>Nahraďte objekt ve stromovém zobrazení. Vyberte prosím starý, nový a nadřazený objekt</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="317"/>
      <source>Remove Objects and their Children</source>
      <translation>Odstranit objekty a jejich potomky</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="320"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Odebere vybrané objekty a všechny potomky, na které se neodkazují jiné objekty</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="530"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Přidat prvek OpenSCAD...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="534"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Přidejte prvek OpenSCAD zadáním kódu OpenSCAD a spuštěním binárního souboru OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="545"/>
      <source>Mesh Boolean...</source>
      <translation>Booleovské operace se sítí...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="549"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Exportujte objekty jako sítě a použijte OpenSCAD k provedení booleovské operace</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="566"/>
      <source>Hull</source>
      <translation>trup, skořepina</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="569"/>
      <source>Use OpenSCAD to create a hull</source>
      <translation>Použít OpenSCAD k vytvoření trupu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../InitGui.py" line="152"/>
      <source>OpenSCAD Tools</source>
      <translation>OpenSCAD soubory</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="156"/>
      <source>Frequently-used Part WB tools</source>
      <translation>Často používané nástroje části WB</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="586"/>
      <source>Minkowski sum</source>
      <translation>Minkowski sum</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="589"/>
      <source>Use OpenSCAD to create a Minkowski sum</source>
      <translation>Použijte OpenSCAD k vytvoření Minkowského součtu</translation>
    </message>
  </context>
</TS>
